
#ifndef FAAC_PARAM_H
#define FAAC_PARAM_H
typedef struct 
{
  uint32_t dummy;
}FAAC_encoderParam;
#endif
